@@ -1,7 +1,7 @@
 /**
  * @file htmlview.h implementation of the item view interface for HTML rendering
  * 
- * Copyright (C) 2006 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2006-2007 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,40 +21,39 @@
 #ifndef _HTMLVIEW_H
 #define _HTMLVIEW_H
 
-#include <gtk/gtk.h>
-
 #include "item.h"
-#include "itemset.h"
 #include "itemview.h"
+#include "node.h"
+#include "ui/ui_htmlview.h"
 
 /* interface for item and item set HTML rendering */
 
 /**
  * Initialize the HTML view 
  */
-void	htmlview_init(void);
+void	htmlview_init (void);
 
 /**
  * To be called to clear the HTML view 
  */
-void	htmlview_clear(void);
+void	htmlview_clear (void);
 
 /**
- * Prepares the HTML view for displaying items of the given item set.
+ * Prepares the HTML view for displaying items of the given node.
  *
- * @param itemSet	the item set that will be rendered
+ * @param node	the node whose items will be rendered
  */
-void	htmlview_set_itemset(itemSetPtr itemSet);
+void	htmlview_set_displayed_node (nodePtr node);
 
 /**
  * Adds an item to the HTML view for rendering. The item must belong
- * to the item set that was announced with ui_htmlview_load_itemset().
+ * to the item set that was announced with htmlview_set_displayed_node().
  *
  * This method _DOES NOT_ update the rendering output.
  *
  * @param item		the item to add to the rendering output
  */
-void	htmlview_add_item(itemPtr item);
+void	htmlview_add_item (itemPtr item);
 
 /**
  * Removes a given item from the HTML view rendering.
@@ -63,7 +62,7 @@ void	htmlview_add_item(itemPtr item);
  *
  * @param item		the item to remove from the rendering output
  */
-void	htmlview_remove_item(itemPtr item);
+void	htmlview_remove_item (itemPtr item);
 
 /**
  * Updates the output of the selected item in the HTML view rendering.
@@ -72,7 +71,7 @@ void	htmlview_remove_item(itemPtr item);
  *
  * @param item		the item to mark for update
  */
-void	htmlview_select_item(itemPtr item);
+void	htmlview_select_item (itemPtr item);
 
 /**
  * Updates the output of a given item in the HTML view rendering.
@@ -81,16 +80,21 @@ void	htmlview_select_item(itemPtr item);
  *
  * @param item		the item to mark for update
  */
-void	htmlview_update_item(itemPtr item);
+void	htmlview_update_item (itemPtr item);
+
+/**
+ * Like htmlview_update_item(), processes all items.
+ */
+void	htmlview_update_all_items (void);
 
 /**
  * Renders all added items to the given HTML view. To be called
  * after one or more calls of htmlview_(add|remove|update)_item.
  *
- * @param widget	HTML widget to render to
+ * @param htmlview	HTML view to render to
  * @param mode		item view mode
  */
-void	htmlview_update(GtkWidget *widget, itemViewMode mode);
+void	htmlview_update (LifereaHtmlView *htmlview, itemViewMode mode);
 
 /** helper methods for HTML output */
 
@@ -102,13 +106,13 @@ void	htmlview_update(GtkWidget *widget, itemViewMode mode);
  * @param css		TRUE if CSS definitions are to be added
  * @param script	TRUE if item menu scripts are to be added
  */
-void	htmlview_start_output(GString *buffer, const gchar *base, gboolean css, gboolean script);
+void	htmlview_start_output (GString *buffer, const gchar *base, gboolean css, gboolean script);
 
 /**
  * Function to add HTML source footer to create a valid HTML source.
  *
  * @param buffer	buffer to add the HTML to
  */
-void	htmlview_finish_output(GString *buffer);
+void	htmlview_finish_output (GString *buffer);
 
 #endif
