@@ -1,7 +1,7 @@
 /**
  * @file mozembed.h common gtkmozembed handling.
  *   
- * Copyright (C) 2003-2006 Lars Lindner <lars.lindner@gmx.net>   
+ * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,19 +23,20 @@
 #define _MOZEMBED_H
 
 #include "mozsupport.h"
+#include "ui/ui_htmlview.h"
 
-void mozembed_write(GtkWidget *widget, const gchar *string, guint length, const gchar *base, const gchar *contentType);
+void mozembed_write (GtkWidget *widget, const gchar *string, guint length, const gchar *base, const gchar *contentType);
 
-GtkWidget * mozembed_create(gboolean forceInternalBrowsing);
+GtkWidget * mozembed_create (LifereaHtmlView *htmlview, gboolean forceInternalBrowsing);
 
-void mozembed_init(void);
+void mozembed_init (void);
 
-void mozembed_deinit(void);
+void mozembed_deinit (void);
 
-void mozembed_launch_url(GtkWidget *widget, const gchar *url);
+void mozembed_launch_url (GtkWidget *widget, const gchar *url);
 
-gboolean mozembed_launch_inside_possible(void);
+gboolean mozembed_launch_inside_possible (void);
 
-void mozembed_set_proxy(gchar *hostname, int port, gchar *username, gchar *password);
+void mozembed_set_proxy (const gchar *hostname, guint port, const gchar *username, const gchar *password);
 
 #endif
