@@ -322,6 +322,12 @@ on_disablejavascript_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 	conf_set_bool_value (DISABLE_JAVASCRIPT, gtk_toggle_button_get_active (togglebutton));
 }
 
+void
+on_allowflash_toggled (GtkToggleButton *togglebutton, gpointer user_data)
+{
+	conf_set_bool_value (ALLOW_FLASH, gtk_toggle_button_get_active (togglebutton));
+}
+
 void
 on_socialsite_changed (GtkOptionMenu *optionmenu, gpointer user_data)
 {
@@ -712,6 +718,10 @@ void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
 		/* set the javascript-disabled flag */
 		widget = liferea_dialog_lookup(prefdialog, "disablejavascript");
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(DISABLE_JAVASCRIPT));
+		
+		/* set the allow Flash flag */
+		widget = liferea_dialog_lookup(prefdialog, "allowflash");
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(ALLOW_FLASH));
 
 		tmp = 0;
 		configuredBrowser = conf_get_str_value(BROWSER_ID);
