@@ -1,7 +1,7 @@
 /**
  * @file xml.h XML helper methods for Liferea
  * 
- * Copyright (C) 2003-2007  Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2009  Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2004-2006  Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -76,6 +76,15 @@ gchar * xhtml_extract (xmlNodePtr cur, gint xhtmlMode, const gchar *defaultBase)
  */
 gchar * xhtml_strip_dhtml (const gchar *html);
 
+/**
+ * Strips Flash embedding tags from the given HTML string.
+ *
+ * @param html	some HTML content
+ *
+ * @return newly allocated stripped HTML string
+ */
+gchar * xhtml_strip_flash (const gchar *html);
+
 /**
  * Convert the given string to proper XHTML content.
  * Note: this function does not respect relative URLs
